@@ -37,7 +37,7 @@ from .extensions import CameraSkybellControllerExtension
 from .extensions import ConfigurationOption
 from .extensions import ExtendedProperties
 
-__version__ = "0.4.1"
+__version__ = "0.4.2"
 
 
 log = logging.getLogger(__name__)
@@ -821,7 +821,7 @@ class AlarmController:
             ) as resp:
                 json_rsp = await resp.json()
 
-                log.debug("Got trouble conditions:\n%s", json_rsp)
+                log.debug("Trouble condition response:\n%s", json_rsp)
 
                 trouble_all_devices: dict = {}
                 for condition in json_rsp.get("data", []):
@@ -863,10 +863,7 @@ class AlarmController:
 
     # Takes EITHER url (without base) or device_type.
     async def _async_get_items_and_subordinates(
-        self,
-        device_type: DeviceType | None = None,
-        url: str | None = None,
-        retry_on_failure: bool = True,
+        self, device_type: DeviceType | None = None, url: str | None = None
     ) -> list:
         """Get attributes, metadata, and child devices for an ADC device class."""
 
@@ -917,23 +914,19 @@ class AlarmController:
                 return []
 
             if rsp_errors[0].get("status") == "403":
-                # This could mean that we're logged out. Try logging in once, then assume bad credentials or some other issue.
+                # User likely has an account without access to this class of device.
+                # I.e. Surety's "Surety Home" plan is alarm only; no cameras, lights, etc.
+                # All requests for those device types will return 403.
+                #
+                # On some providers, 403 may mean that the user has been logged out.
+                # For now, we'll ignore this case.
 
-                log.error("Error fetching data from Alarm.com.")
-
-                if not retry_on_failure:
-                    log.error("Giving up.")
-                    raise BadAccount
-
-                log.error("Trying to refresh auth tokens by logging in again.")
-
-                await self.async_login()
-
-                return await self._async_get_items_and_subordinates(
-                    device_type=device_type,
-                    retry_on_failure=False,
+                log.debug(
+                    "Got 403 status when fetching data for device type %s.", device_type
                 )
 
+                return list([])
+
             if (
                 rsp_errors[0].get("status") == "409"
                 and rsp_errors[0].get("detail") == "TwoFactorAuthenticationRequired"
